@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 use base 'Exporter';
-our @EXPORT_OK = qw(convert_image);
+our @EXPORT_OK = qw(create_thumbnail);
 
-our $VERSION = '0.5.4';
+our $VERSION = '0.5.5';
 
 require XSLoader;
 XSLoader::load('Ithumb::XS', $VERSION);
